"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var tslint_1 = require("tslint");
var validators_1 = require("./validators");
var walkers_1 = require("./walkers");
var Rule = (function (_super) {
    tslib_1.__extends(Rule, _super);
    function Rule() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Rule.prototype.apply = function (sourceFile) {
        return this.applyWithWalker(new EnumMemberNameWalker(sourceFile, this.ruleName, this.ruleArguments));
    };
    return Rule;
}(tslint_1.Rules.AbstractRule));
exports.Rule = Rule;
var EnumMemberNameWalker = (function (_super) {
    tslib_1.__extends(EnumMemberNameWalker, _super);
    function EnumMemberNameWalker() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.validator = new EnumMemberCaseValidator(_this.options, "pascal-case");
        return _this;
    }
    EnumMemberNameWalker.prototype.visitEnumDeclaration = function (node) {
        node.members.forEach(this.visitEnumMember, this);
    };
    EnumMemberNameWalker.prototype.visitEnumMember = function (node) {
        this.visitEnumMemberName(node.name);
    };
    EnumMemberNameWalker.prototype.visitEnumMemberName = function (node) {
        this.checkEnumMemberName(node, node.getText());
    };
    EnumMemberNameWalker.prototype.checkEnumMemberName = function (node, name) {
        if (!this.validator.test(name)) {
            this.addFailureAtNode(node, this.validator.message);
        }
    };
    return EnumMemberNameWalker;
}(walkers_1.EnumDeclarationWalker));
var EnumMemberCaseValidator = (function (_super) {
    tslib_1.__extends(EnumMemberCaseValidator, _super);
    function EnumMemberCaseValidator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    EnumMemberCaseValidator.prototype.toMessage = function (name) {
        return "Enum members must be in " + name;
    };
    return EnumMemberCaseValidator;
}(validators_1.CaseValidator));
//# sourceMappingURL=enumMemberNameRule.js.map