"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var tslint_1 = require("tslint");
var validators_1 = require("./validators");
var walkers_1 = require("./walkers");
var Rule = (function (_super) {
    tslib_1.__extends(Rule, _super);
    function Rule() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    Rule.prototype.apply = function (sourceFile) {
        return this.applyWithWalker(new EnumNameWalker(sourceFile, this.ruleName, this.ruleArguments));
    };
    return Rule;
}(tslint_1.Rules.AbstractRule));
exports.Rule = Rule;
var EnumNameWalker = (function (_super) {
    tslib_1.__extends(EnumNameWalker, _super);
    function EnumNameWalker() {
        var _this = _super !== null && _super.apply(this, arguments) || this;
        _this.validator = new EnumNameCaseValidator(_this.options, "pascal-case");
        return _this;
    }
    EnumNameWalker.prototype.visitEnumDeclaration = function (node) {
        this.visitEnumName(node.name);
    };
    EnumNameWalker.prototype.visitEnumName = function (node) {
        this.checkEnumName(node, node.getText());
    };
    EnumNameWalker.prototype.checkEnumName = function (node, name) {
        if (!this.validator.test(name)) {
            this.addFailureAtNode(node, this.validator.message);
        }
    };
    return EnumNameWalker;
}(walkers_1.EnumDeclarationWalker));
var EnumNameCaseValidator = (function (_super) {
    tslib_1.__extends(EnumNameCaseValidator, _super);
    function EnumNameCaseValidator() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    EnumNameCaseValidator.prototype.toMessage = function (name) {
        return "Enum names must be in " + name;
    };
    return EnumNameCaseValidator;
}(validators_1.CaseValidator));
//# sourceMappingURL=enumNameRule.js.map